==> orangehrm-2.4.1.tbz: www/orangehrm/lib/common/yui.php <==
<?php
/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 *
 */
?>
<link type="text/css" rel="stylesheet" href="<?php echo $_SESSION['WPATH']; ?>/themes/<?php echo $_SESSION['styleSheet']; ?>/css/yui/fonts/fonts.css">
<link type="text/css" rel="stylesheet" href="<?php echo $_SESSION['WPATH']; ?>/themes/<?php echo $_SESSION['styleSheet']; ?>/css/yui/container/assets/container.css">
<link type="text/css" rel="stylesheet" href="<?php echo $_SESSION['WPATH']; ?>/themes/<?php echo $_SESSION['styleSheet']; ?>/css/yui/calendar/assets/calendar.css">
<link type="text/css" rel="stylesheet" href="<?php echo $_SESSION['WPATH']; ?>/themes/<?php echo $_SESSION['styleSheet']; ?>/css/yui/button/assets/button.css">

<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/yahoo/yahoo-min.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/event/event-min.js" ></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/dom/dom-min.js" ></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/container/container-min.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/yahoo-dom-event/yahoo-dom-event.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/element/element-beta-min.js"></script>

<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/calendar/calendar.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/button/button-beta-min.js"></script>

<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/animation/animation-min.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/autocomplete/autocomplete-min.js"></script>

==> orangehrm-2.7.tbz: www/orangehrm/lib/common/yui.php <==
<?php
/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 *
 */
?>
<link type="text/css" rel="stylesheet" href="<?php echo $_SESSION['WPATH']; ?>/themes/<?php echo $_SESSION['styleSheet']; ?>/css/yui/fonts/fonts.css" />
<link type="text/css" rel="stylesheet" href="<?php echo $_SESSION['WPATH']; ?>/themes/<?php echo $_SESSION['styleSheet']; ?>/css/yui/container/assets/container.css" />
<link type="text/css" rel="stylesheet" href="<?php echo $_SESSION['WPATH']; ?>/themes/<?php echo $_SESSION['styleSheet']; ?>/css/yui/calendar/assets/calendar.css" />
<link type="text/css" rel="stylesheet" href="<?php echo $_SESSION['WPATH']; ?>/themes/<?php echo $_SESSION['styleSheet']; ?>/css/yui/button/assets/button.css" />

<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/yahoo/yahoo-min.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/event/event-min.js" ></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/dom/dom-min.js" ></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/container/container-min.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/yahoo-dom-event/yahoo-dom-event.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/element/element-beta-min.js"></script>

<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/calendar/calendar.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/button/button-beta-min.js"></script>

<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/animation/animation-min.js"></script>
<script type="text/javascript" src="<?php echo $_SESSION['WPATH']; ?>/scripts/yui/autocomplete/autocomplete-min.js"></script>
